package com.plannaplan.repositories;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringRunner;

import static org.junit.Assert.assertTrue;

import java.util.List;

import com.plannaplan.entities.Assignment;
import com.plannaplan.entities.Commision;
import com.plannaplan.entities.Groups;
import com.plannaplan.entities.User;
import com.plannaplan.services.AssignmentService;
import com.plannaplan.services.CommisionService;
import com.plannaplan.services.GroupService;
import com.plannaplan.services.UserService;
import com.plannaplan.types.UserRoles;
import com.plannaplan.types.WeekDay;

import org.junit.Test;

import org.junit.runner.RunWith;

@RunWith(SpringRunner.class)
@SpringBootTest
@ContextConfiguration
public class GroupRepositoryTest {
        @Autowired
        private GroupRepository repository;
        @Autowired
        private AssignmentService assignmentService;
        @Autowired
        private GroupService groupService;
        @Autowired
        private UserService userService;

        @Autowired
        private CommisionService commisionService;

        @Test
        public void shouldReturnGroupAssignmentTimes() throws InterruptedException {
                final Groups testGroup = groupService.save(new Groups(43, "A-41", null, 235, WeekDay.MONDAY, null));
                int startGroupAmmount = this.repository.getAssignedAmount(testGroup.getId()).orElse(Integer.valueOf(0))
                                .intValue();

                final User user = this.userService.save(new User("Luis", "Vita",
                                "shouldReturnGroupAssignmentTimes@grouprepository.test", UserRoles.STUDENT));
                final Commision commision = this.commisionService.save(new Commision(user));

                this.assignmentService.save(new Assignment(testGroup, commision));
                Thread.sleep(1000);

                int afterAssignedGroupAmmount = this.repository.getAssignedAmount(testGroup.getId())
                                .orElse(Integer.valueOf(0)).intValue();

                assertTrue(afterAssignedGroupAmmount > startGroupAmmount);

                final Commision recommision = this.commisionService.save(new Commision(user));
                this.assignmentService.save(new Assignment(testGroup, recommision));

                Thread.sleep(1000);

                int afterreAssignedGroupAmmount = this.repository.getAssignedAmount(testGroup.getId())
                                .orElse(Integer.valueOf(0)).intValue();

                assertTrue(afterAssignedGroupAmmount == afterreAssignedGroupAmmount);

                this.commisionService.save(new Commision(user));

                Thread.sleep(1000);

                int afterdeAssignedGroupAmmount = this.repository.getAssignedAmount(testGroup.getId())
                                .orElse(Integer.valueOf(0)).intValue();

                assertTrue(afterdeAssignedGroupAmmount < afterreAssignedGroupAmmount);

        }

        @Test
        public void shouldReturnGroupAssignmentTimesList() throws InterruptedException {
                final Groups testGroup = groupService.save(new Groups(43, "A-41", null, 645, WeekDay.MONDAY, null));
                final Groups testGroup2 = groupService.save(new Groups(433, "A-41", null, 235, WeekDay.TUESDAY, null));
                final Groups testGroup3 = groupService.save(new Groups(23, "A-41", null, 340, WeekDay.MONDAY, null));
                final User user = this.userService.save(new User("Dare", "Oc",
                                "shouldReturnGroupAssignmentTimesList@grouprepository.test", UserRoles.STUDENT));
                final Commision commision = this.commisionService.save(new Commision(user));

                this.assignmentService.save(new Assignment(testGroup, commision));
                this.assignmentService.save(new Assignment(testGroup2, commision));
                this.assignmentService.save(new Assignment(testGroup3, commision));

                Thread.sleep(1000);

                List<Object[]> response = this.repository
                                .getAssignedAmounts(List.of(testGroup.getId(), testGroup2.getId(), testGroup3.getId()));

                assertTrue("Response should have size 3", response.size() == 3);
                assertTrue("Instance of firest element should be Group", response.get(0)[0] instanceof Groups);
                assertTrue("Instance of firest element should be Long", response.get(0)[1] instanceof Long);

        }

}
